# SEP
Semantic Evaluation Platform 

[![Build Status](https://travis-ci.com/Fafa87/SEP.svg?branch=master)](https://travis-ci.com/Fafa87/SEP)
[![GitHub release](https://img.shields.io/github/release/Fafa87/SEP.svg)](https://GitHub.com/Fafa87/SEP/releases/)

[![PyPI version](https://img.shields.io/pypi/v/semevalplatform.svg)](https://pypi.org/project/semevalplatform/)
[![PyPi](https://img.shields.io/pypi/pyversions/semevalplatform)](https://pypi.org/project/semevalplatform/)
![Platform](https://img.shields.io/badge/platform-windows%20%7C%20osx%20%7C%20ubuntu-lightgrey)
